# Generated by Django 5.1.5 on 2025-02-07 10:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("cesnet_service_path_plugin", "0015_merge_notes_to_comments"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="segment",
            name="note_a",
        ),
        migrations.RemoveField(
            model_name="segment",
            name="note_b",
        ),
    ]
