# Generated by Django 5.1.5 on 2025-02-10 08:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "cesnet_service_path_plugin",
            "0019_alter_servicepathsegmentmapping_options_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="servicepath",
            options={"ordering": ("name", "status", "kind")},
        ),
        migrations.AddField(
            model_name="segment",
            name="status",
            field=models.CharField(default="active", max_length=30),
        ),
        migrations.AddField(
            model_name="servicepath",
            name="status",
            field=models.CharField(default="active", max_length=30),
        ),
    ]
