# Generated by Django 5.0.6 on 2024-07-12 11:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cesnet_service_path_plugin", "0007_segment_comments"),
    ]

    operations = [
        migrations.AddField(
            model_name="servicepath",
            name="comments",
            field=models.TextField(blank=True),
        ),
    ]
