<!-- Common Status Colors Configuration -->
<script>
// Status color mapping - shared across all map templates
const statusColors = {
    "Active": "#dc3545",       // Red - more visible on OSM
    "Planned": "#ff6b35",      // Orange-red 
    "Offline": "#dc3545",      // Red
    "Decommissioned": "#6c757d" // Gray
};
</script>