# Generated by Django 5.1.5 on 2025-02-07 08:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("cesnet_service_path_plugin", "0013_alter_segment_table_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="segment",
            name="imported_data",
        ),
        migrations.RemoveField(
            model_name="segment",
            name="komora_id",
        ),
        migrations.RemoveField(
            model_name="servicepath",
            name="imported_data",
        ),
        migrations.RemoveField(
            model_name="servicepath",
            name="komora_id",
        ),
        migrations.RemoveField(
            model_name="servicepathsegmentmapping",
            name="imported_data",
        ),
        migrations.RemoveField(
            model_name="servicepathsegmentmapping",
            name="komora_id",
        ),
    ]
