# Generated by Django 5.1.5 on 2025-02-07 10:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "cesnet_service_path_plugin",
            "0017_remove_segment_device_a_remove_segment_device_b_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="segment",
            name="sync_status",
        ),
        migrations.RemoveField(
            model_name="servicepath",
            name="sync_status",
        ),
    ]
