{% load i18n %}
<div class="col col-md-12">
    <div class="card">
        <h5 class="card-header">
            {% trans "Segments" %}
            <div class="card-actions">
                <a href="{% url 'plugins:cesnet_service_path_plugin:segmentcircuitmapping_add' %}?circuit={{ object.pk }}&return_url={{ request.path }}"
                   class="btn btn-ghost-primary btn-sm">
                    <i class="mdi mdi-plus-thick" aria-hidden="true"></i> {% trans "Add a Segment" %}
                </a>
            </div>
        </h5>
        {% htmx_table 'plugins:cesnet_service_path_plugin:segmentcircuitmapping_list' circuit_id=object.pk %}
    </div>
</div>
