# Generated by Django 5.0.6 on 2024-08-27 07:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "cesnet_service_path_plugin",
            "0011_remove_segment_supplier_alter_segment_provider",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="segment",
            name="sync_status",
            field=models.CharField(default="active", max_length=30),
        ),
        migrations.AddField(
            model_name="servicepath",
            name="sync_status",
            field=models.CharField(default="active", max_length=30),
        ),
    ]
