{% extends 'generic/object_list.html' %}
{% load static %}
{% load helpers %}

{% block title %}Segments{% endblock %}

{% block extra_controls %}
    {{ block.super }}
    <div class="btn-group" role="group">
        <a href="{% url 'plugins:cesnet_service_path_plugin:segments_map' %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" 
           class="btn btn-outline-primary">
            <i class="mdi mdi-map" aria-hidden="true"></i> Map View
        </a>
    </div>
{% endblock %}