# Generated by Django 5.2.3 on 2025-07-08 09:46

import django.contrib.gis.db.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cesnet_service_path_plugin', '0023_alter_servicepath_kind'),
    ]

    operations = [
        migrations.AddField(
            model_name='segment',
            name='path_geometry',
            field=django.contrib.gis.db.models.fields.LineStringField(blank=True, null=True, srid=4326),
        ),
        migrations.AddField(
            model_name='segment',
            name='path_length_km',
            field=models.DecimalField(blank=True, decimal_places=3, max_digits=10, null=True),
        ),
        migrations.AddField(
            model_name='segment',
            name='path_notes',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='segment',
            name='path_source_format',
            field=models.CharField(blank=True, max_length=20, null=True),
        ),
    ]
