# Generated by Django 5.1.5 on 2025-02-07 13:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("cesnet_service_path_plugin", "0018_remove_segment_sync_status_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="servicepathsegmentmapping",
            options={"ordering": ("service_path", "segment")},
        ),
        migrations.AlterUniqueTogether(
            name="servicepathsegmentmapping",
            unique_together={("service_path", "segment")},
        ),
        migrations.RemoveField(
            model_name="servicepathsegmentmapping",
            name="index",
        ),
    ]
