# Generated by Django 4.2.8 on 2024-05-07 11:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cesnet_service_path_plugin", "0003_servicepathsegmentmapping"),
    ]

    operations = [
        migrations.AddField(
            model_name="segment",
            name="komora_id",
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="servicepath",
            name="imported_data",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="servicepath",
            name="komora_id",
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="servicepathsegmentmapping",
            name="imported_data",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="servicepathsegmentmapping",
            name="komora_id",
            field=models.BigIntegerField(blank=True, null=True),
        ),
    ]
