# Generated by Django 5.0.6 on 2024-07-11 12:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "cesnet_service_path_plugin",
            "0005_segmentcircuitmapping_segment_circuits_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="servicepath",
            name="circuits",
        ),
        migrations.DeleteModel(
            name="ServicePathCircuitMapping",
        ),
    ]
