# Generated by Django 5.1.5 on 2025-02-10 08:16

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("cesnet_service_path_plugin", "0021_copy_service_path_state_to_status"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="servicepath",
            options={"ordering": ("name", "status", "kind")},
        ),
        migrations.RemoveField(
            model_name="servicepath",
            name="state",
        ),
    ]
